@@ -6,28 +6,28 @@ from ckanext.list.lib import get_datastore_fields
 def test_get_datastore_fields():
     result = {
         'fields': [
-            {
-                'id': 'beans'
-            },
-            {
-                'id': 'lemons'
-            },
-            {
-                'id': 'goats'
-            },
+            {'id': 'beans'},
+            {'id': 'lemons'},
+            {'id': 'goats'},
         ]
     }
-    mock_toolkit = MagicMock(get_action=MagicMock(return_value=MagicMock(return_value=result)))
+    mock_toolkit = MagicMock(
+        get_action=MagicMock(return_value=MagicMock(return_value=result))
+    )
 
     with patch('ckanext.list.lib.toolkit', mock_toolkit):
-        assert get_datastore_fields(MagicMock(), MagicMock()) == ['beans', 'goats', 'lemons']
+        assert get_datastore_fields(MagicMock(), MagicMock()) == [
+            'beans',
+            'goats',
+            'lemons',
+        ]
 
 
 def test_get_datastore_fields_empty():
-    result = {
-        'fields': []
-    }
-    mock_toolkit = MagicMock(get_action=MagicMock(return_value=MagicMock(return_value=result)))
+    result = {'fields': []}
+    mock_toolkit = MagicMock(
+        get_action=MagicMock(return_value=MagicMock(return_value=result))
+    )
 
     with patch('ckanext.list.lib.toolkit', mock_toolkit):
         assert get_datastore_fields(MagicMock(), MagicMock()) == []
@@ -35,7 +35,9 @@ def test_get_datastore_fields_empty():
 
 def test_get_datastore_fields_missing():
     result = {}
-    mock_toolkit = MagicMock(get_action=MagicMock(return_value=MagicMock(return_value=result)))
+    mock_toolkit = MagicMock(
+        get_action=MagicMock(return_value=MagicMock(return_value=result))
+    )
 
     with patch('ckanext.list.lib.toolkit', mock_toolkit):
         assert get_datastore_fields(MagicMock(), MagicMock()) == []
